--============================================================================================--
--============================================================================================--
--																							--
--							  ITEM, BAG, TOOLTIP FUNCTIONS								  --
--																							--
--============================================================================================--
--============================================================================================--

--GetContainerItemLink item name strfind syntax
local WARDROBE_ITEM_NAME_FROM_LINK = "|h%[(.-)%]|h";

---------------------------------------------------------------------------------
-- Return the name of the item in the specified player's inventory slot number 
-- (1 = "headslot" etc - see Wardrobe.InventorySlots above for a full list of the slots)
---------------------------------------------------------------------------------
function Wardrobe.GetItemNameAtInventorySlotNumber(slotNum)

	local itemName, _ = "";
	-- get the id number for the item slot
	local id = GetInventorySlotInfo(Wardrobe.InventorySlots[slotNum]);
	local linktext = GetInventoryItemLink("player", id);
	if (linktext) then
		_,_,itemName = strfind(linktext, WARDROBE_ITEM_NAME_FROM_LINK);
	end
	return itemName;
end


---------------------------------------------------------------------------------
-- Find the named item on the character's inventory (head slot, hand slot, etc -- not bags)
---------------------------------------------------------------------------------
function Wardrobe.FindInventoryItem(targetItemName)

	local foundItem = false;
	
	for i = 1, table.getn(Wardrobe.InventorySlots) do
	
		if (Wardrobe.GetItemNameAtInventorySlotNumber(i) == targetItemName) then
			foundItem = true;
			break;
		end
	end
	
	return foundItem;
end


---------------------------------------------------------------------------------
-- Return the name of the item in the specified bag and slot
---------------------------------------------------------------------------------
function Wardrobe.GetItemNameInBagSlot(bagNum, slotNum)
	
	local itemName, _ = "";
	local linktext = GetContainerItemLink(bagNum, slotNum)
	if (linktext) then
		_,_,itemName = strfind(linktext, WARDROBE_ITEM_NAME_FROM_LINK);
	end
	
	return itemName;
end

---------------------------------------------------------------------------------
-- Given the name of an item, find the bag and slot the item is in
---------------------------------------------------------------------------------
function Wardrobe.FindContainerItem(targetItemName)
	local foundBag = nil;
	local foundSlot = nil;
	--Wardrobe.Debug("	Looking in inventory for ["..targetItemName.."]");	
	
   -- for each bag and slot
   if ( Wardrobe.InventorySearchForward == 1 ) then
	bagcounterA = 0
	bagcounterB = NUM_CONTAINER_FRAMES
   else
	bagcounterB = 0
	bagcounterA = NUM_CONTAINER_FRAMES
   end

	for bag = bagcounterA, bagcounterB, Wardrobe.InventorySearchForward do
		local frame = getglobal("ContainerFrame"..bag);
	local counterA = 1
	local counterB = 1

	if ( Wardrobe.InventorySearchForward == 1 ) then
		counterA = 1
		counterB = GetContainerNumSlots(bag)
	else
		counterB = 1
		counterA = GetContainerNumSlots(bag)
	end
		for slot = counterA, counterB, Wardrobe.InventorySearchForward do
		
			-- get the name of the item in this bag/slot
			bagItemName = Wardrobe.GetItemNameInBagSlot(bag, slot);
			Wardrobe.Debug("		 Comparing with "..bagItemName.." Bag:"..bag.." Slot:"..slot);
			
			-- if it matches what we're looking for
			if (targetItemName == bagItemName) then
			   Wardrobe.Debug("		   FOUND in bag = "..bag.." slot = "..slot);
				foundBag  = bag;
				foundSlot = slot;
				break;
			end
		end
		if (foundBag and foundSlot) then
			break;
		end
	end

	if ( Wardrobe.InventorySearchForward == 1 ) then
		Wardrobe.InventorySearchForward = -1
	else
		Wardrobe.InventorySearchForward = 1
	end
	
	return foundBag, foundSlot;
end


---------------------------------------------------------------------------------
-- Build a list of items in our bags and on our person
---------------------------------------------------------------------------------
function Wardrobe.BuildItemList()

	tempList = {};
	
	-- for each bag and slot
	for bag = 0, NUM_CONTAINER_FRAMES, 1 do
		local frame = getglobal("ContainerFrame"..bag);
		for slot = 1, GetContainerNumSlots(bag) do
		
			-- get the name of the item in this bag/slot
			local itemName = Wardrobe.GetItemNameInBagSlot(bag, slot);
			if (itemName ~= "") then
				table.insert(tempList, itemName);		  
			end
		end
	end

	-- for each inventory item
	for i = 1, table.getn(Wardrobe.InventorySlots) do   
		local itemName = Wardrobe.GetItemNameAtInventorySlotNumber(i);
		if (itemName ~= "") then
			table.insert(tempList, itemName);		  
		end
	end

	
	return tempList;	
end



---------------------------------------------------------------------------------
-- Equip the specified item into the specified slot on our character (hands, chest, etc)
---------------------------------------------------------------------------------
function Wardrobe.Equip(itemName, equipSlot)

	-- if we're already holding something, bail
	if (CursorHasItem()) then
		return false;
	end
	
	-- find the bag and slot of this item
	local bag, slot = Wardrobe.FindContainerItem(itemName);
	if (bag and slot) then
		PickupContainerItem(bag, slot);
		if (equipSlot) and (equipSlot >= 11) and (equipSlot <= 17) and (equipSlot ~= 15) then
			--Fingers, Trinkets, Weapons
			--PickupInventoryItem(equipSlot);
			EquipCursorItem(equipSlot);
		else
			AutoEquipCursorItem();
		end
		return true;
	end
	return false;
end


---------------------------------------------------------------------------------
-- Check to see if the specified outfit name is already being used
---------------------------------------------------------------------------------
function Wardrobe.FoundOutfitName(outfitName)
	local foundOutfit = false;
	
	for i = 1, table.getn(Wardrobe_Config[WD_realmID][WD_charID].Outfit) do
		if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].OutfitName == outfitName) then
			foundOutfit = true;
			break;
		end
	end
	
	return foundOutfit;
end


---------------------------------------------------------------------------------
-- Return the index of the specified outfitName
---------------------------------------------------------------------------------
function Wardrobe.GetOutfitNum(outfitName)
	local outfitNum = nil;
	
	for i = 1, table.getn(Wardrobe_Config[WD_realmID][WD_charID].Outfit) do
		if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].OutfitName == outfitName) then
			outfitNum = i;
			break;
		end
	end
	
	return outfitNum;
end



---------------------------------------------------------------------------------
-- See if this bag / slot is being used or is free
---------------------------------------------------------------------------------
function Wardrobe.UsedThisSlot(freeBagSpacesUsed, theBag, theSlot)
	for i = 1, table.getn(freeBagSpacesUsed) do
		if (freeBagSpacesUsed[i][1] == theBag and freeBagSpacesUsed[i][2] == theSlot) then
			return true;
		end
	end
	return false;
end


---------------------------------------------------------------------------------
-- Put an item into a free bag slot
---------------------------------------------------------------------------------
function BagItem(freeBagSpacesUsed)

	-- for each bag and slot
	for theBag = 0, 4, 1 do
		local numSlot = GetContainerNumSlots(theBag);
		for theSlot = 1, numSlot, 1 do
		
			-- get info about the item here
			local texture, itemCount, locked = GetContainerItemInfo(theBag, theSlot);
			
			-- if we found nothing, add us to the list of free bag slots
			if (not texture and not Wardrobe.UsedThisSlot(freeBagSpacesUsed, theBag, theSlot)) then
				PickupContainerItem(theBag,theSlot);
				table.insert(freeBagSpacesUsed, {theBag, theSlot});
				return true, freeBagSpacesUsed;
			end
		end
	end
	
	AutoEquipCursorItem();
	
	return false, freeBagSpacesUsed;
end

