--============================================================================================--
--============================================================================================--
--																							--
--							  INTERFACE FUNCTIONS											 --
--																							--
--============================================================================================--
--============================================================================================--


--===============================================================================
--
-- UI Menu and Button
--
--===============================================================================

---------------------------------------------------------------------------------
-- Start dragging the wardrobe button
---------------------------------------------------------------------------------
function Wardrobe.OnDragStart()
	if (not Wardrobe.DragLock) then
		Wardrobe.IconFrame:StartMoving()
		Wardrobe.BeingDragged = true;
	end
end


---------------------------------------------------------------------------------
-- Stop dragging the wardrobe button
---------------------------------------------------------------------------------
function Wardrobe.OnDragStop()
	if (Wardrobe.BeingDragged) then
		Wardrobe.IconFrame:StopMovingOrSizing()
		Wardrobe.BeingDragged = false;
		local x,y = this:GetCenter();
		local px,py = this:GetParent():GetCenter();
		local ox = x-px;
		local oy = y-py;
		Wardrobe_Config.xOffset = ox;
		Wardrobe_Config.yOffset = oy;
	end
end


---------------------------------------------------------------------------------
-- Toggle whether the wardrobe button can be moved or not
---------------------------------------------------------------------------------
function Wardrobe.ToggleLockButton(toggle)
	Wardrobe.DragLock = toggle;
	if (Wardrobe.DragLock) then
		Wardrobe.Print(WARDROBE_CONSTANTS_TXT_BUTTONLOCKED);
	else
		Wardrobe.Print(WARDROBE_CONSTANTS_TXT_BUTTONUNLOCKED);
	end
end

---------------------------------------------------------------------------------
-- Toggle whether the wardrobe menu requires a click of the button to show
---------------------------------------------------------------------------------
function Wardrobe.ToggleClickButton(toggle)
	Wardrobe_Config.MustClickUIButton = toggle;
	if (Wardrobe_Config.MustClickUIButton) then
		Wardrobe.Print(WARDROBE_CONSTANTS_TXT_BUTTONONCLICK);
	else
		Wardrobe.Print(WARDROBE_CONSTANTS_TXT_BUTTONONMOUSEOVER);
	end
end


---------------------------------------------------------------------------------
-- Register the wardrobe button 
---------------------------------------------------------------------------------
function Wardrobe.ButtonOnLoad()
	this:RegisterForDrag("LeftButton");
	if (MobileMinimapButtons_AddButton) then
		MobileMinimapButtons_AddButton("Wardrobe_IconFrame", WARDROBE_CONSTANTS_TXT_WARDROBEBUTTON);
	end
end


---------------------------------------------------------------------------------
-- Update function for showing/hiding the wardrobe button 
---------------------------------------------------------------------------------
function Wardrobe.ButtonUpdateVisibility()
	if (TitanGetVar) then
		if (TitanGetVar(WARDROBE_TITAN_ID, "ShowMinimapIcon")) then
    		Wardrobe_Config[WD_realmID][WD_charID].MinimapButtonVisible = 1;
        	Wardrobe.IconFrame:Show();
        else
        	Wardrobe_Config[WD_realmID][WD_charID].MinimapButtonVisible = 0;
			Wardrobe.IconFrame:Hide();
		end
    elseif (not Wardrobe_Config[WD_realmID][WD_charID].MinimapButtonVisible) or (Wardrobe_Config[WD_realmID][WD_charID].MinimapButtonVisible == 1) then
    	Wardrobe_Config[WD_realmID][WD_charID].MinimapButtonVisible = 1;
    	Wardrobe.IconFrame:Show();
    else
        Wardrobe.IconFrame:Hide();
    end
end


---------------------------------------------------------------------------------
-- Update function for showing/hiding the UI menu
---------------------------------------------------------------------------------
function Wardrobe.OnUpdateUIMenu(elapsed)
	Wardrobe.Popup.updateTimer = Wardrobe.Popup.updateTimer + elapsed;
	if (Wardrobe.Popup.updateTimer > 2) then
		if (not MouseIsOver(Wardrobe.Popup) and not MouseIsOver(Wardrobe.IconFrame)) then
			if IsAddOnLoaded("Titan") then
				if not MouseIsOver(TitanPanelWardrobeButton) then
					Wardrobe.Popup:Hide();
				end
			else
				Wardrobe.Popup:Hide();
			end
		end
	end
end


---------------------------------------------------------------------------------
-- When the user clicks on the UI button (currently disabled)
---------------------------------------------------------------------------------
function Wardrobe.HandleUIMenuTriggerClick()
	if (Wardrobe_Config.MustClickUIButton) then
		Wardrobe.ShowUIMenu();
	end			
end


---------------------------------------------------------------------------------
-- When the user mouses over the UI button
---------------------------------------------------------------------------------
function Wardrobe.HandleUIMenuTriggerEnter()
	if (not Wardrobe_Config.MustClickUIButton) then
		-- turn on color cycling for Wardrobe.PopupTitle
		Wardrobe.ColorCycle_UIPopupMenu(true);
		Wardrobe.ShowUIMenu();
	end
end


---------------------------------------------------------------------------------
-- When the user mouses off the UI button
---------------------------------------------------------------------------------
function Wardrobe.HandleUIMenuTriggerLeave()
	-- turn off color cycling for Wardrobe.PopupTitle
	Wardrobe.ColorCycle_UIPopupMenu(false);
	GameTooltip:Hide();
end


---------------------------------------------------------------------------------
-- Begin the process of displaying the UI menu
---------------------------------------------------------------------------------
function Wardrobe.ShowUIMenu()
	
	Wardrobe.Popup:SetPoint("TOPRIGHT", Wardrobe.IconFrame, "TOPLEFT", 0, 0);
	
	-- if we haven't already looked up our character's number
	Wardrobe.CheckForOurWardrobeID();
	
	-- update the availability of our outfits
	Wardrobe.UpdateOutfitAvailability();

	-- find out if we're wearing one of our outfits
	Wardrobe.ActiveOutfitList = Wardrobe.DetermineActiveOutfit();

	Wardrobe.CompleteShowingUIMenu();
end


---------------------------------------------------------------------------------
-- Complete the process of displaying the UI menu
---------------------------------------------------------------------------------
function Wardrobe.CompleteShowingUIMenu()

	Wardrobe.Debug("Wardrobe.CompleteShowingUIMenu called!");
	
	-- set the title of the popup window
	Wardrobe.PopupTitle:SetText(UnitName("player").."'s "..WARDROBE_CONSTANTS_TEXT_MENU_TITLE);
	
	-- Set the text for the buttons while keeping track of how many
	-- buttons we actually need.
	local count = 0;
	for i = 1, table.getn(Wardrobe_Config[WD_realmID][WD_charID].Outfit) do
		if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].OutfitName ~= "" and (not Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Virtual)) then
			count = count + 1;
			local button = Wardrobe["PopupButton"..count];
			button:SetText(Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].OutfitName);
			
			-- determine if we're wearing all the items in this outfit
			local activeOutfit = false;
			for j = 1, table.getn(Wardrobe.ActiveOutfitList) do
				if (Wardrobe.ActiveOutfitList[j] == i) then
					activeOutfit = true;
					break;
				end
			end
			
			local fullOutfitSet = true;
			for j = 1, table.getn(Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Item) do
				if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Item[j].IsSlotUsed ~= 1) then
					fullOutfitSet = false;
					break;
				end
			end
			
			-- color the buttons based on wardrobe availability
			local buttonColor = Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].ButtonColor;
			if (activeOutfit) then
				button:SetTextColor(WARDROBE_CONSTANTS_TEXTCOLORS[buttonColor][1], WARDROBE_CONSTANTS_TEXTCOLORS[buttonColor][2], WARDROBE_CONSTANTS_TEXTCOLORS[buttonColor][3]);
			elseif (Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Available) then
				button:SetTextColor(WARDROBE_CONSTANTS_DRABCOLORS[buttonColor][1], WARDROBE_CONSTANTS_DRABCOLORS[buttonColor][2], WARDROBE_CONSTANTS_DRABCOLORS[buttonColor][3]);
			else
				button:SetTextColor(0.70, 0.76, 0.65);
			end
			button.OutfitName = Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].OutfitName;
			button:Show();
		end
	end
	
	-- add in the "add" and "delete" and "rename" and "sort" buttons
	count = count + 1;
	local button = Wardrobe["PopupButton"..count];
	button:SetText("[Menu]");
	button.OutfitName = "[Menu]";
	button:SetTextColor(1.0, 1.0, 1.0);
	button:Show();
	
	-- Set the width for the menu.
	local width = Wardrobe.PopupTitle:GetWidth();
	for i = 1, count, 1 do
		local button = Wardrobe["PopupButton"..i];
		local w = button:GetTextWidth();
		if (w > width) then
			width = w;
		end
	end
	Wardrobe.Popup:SetWidth(width + 2 * UNITPOPUP_BORDER_WIDTH);

	-- By default, the width of the button is set to the width of the text
	-- on the button.  Set the width of each button to the width of the
	-- menu so that you can still click on it without being directly
	-- over the text.
	for i = 1, count, 1 do
		local button = Wardrobe["PopupButton"..i];
		button:SetWidth(width);
	end

	-- Hide the buttons we don't need.
	for i = count + 1, WARDROBE_CONSTANTS_NUM_OUTFITS + WARDROBE_CONSTANTS_NUM_POPUP_FUNCTION_BUTTONS do
		local button = Wardrobe["PopupButton"..i];
		button:Hide();
	end
	
	-- Set the height for the menu.
	Wardrobe.Popup:SetHeight(UNITPOPUP_TITLE_HEIGHT + (count * (UNITPOPUP_BUTTON_HEIGHT - 3)) + (3 * UNITPOPUP_BORDER_HEIGHT));

	-- Show the menu.
	Wardrobe.Popup:Show();
	
end


---------------------------------------------------------------------------------
-- Handle when a user clicks on an outfit button in the UI menu
---------------------------------------------------------------------------------
function Wardrobe.ButtonClick()
	if (this.OutfitName == "[Menu]") then
		Wardrobe.ShowMainMenu();		
	else
		Wardrobe.WearOutfit(this.OutfitName);
	end
		
	Wardrobe.Popup:Hide();
end


---------------------------------------------------------------------------------
-- Handle keybinding clicks
---------------------------------------------------------------------------------
function Wardrobe.Keybinding(outfitNum)
	if (outfitNum <= table.getn(Wardrobe_Config[WD_realmID][WD_charID].Outfit)) then
		Wardrobe.WearOutfit(Wardrobe_Config[WD_realmID][WD_charID].Outfit[outfitNum].OutfitName);
	end
end


--===============================================================================
--
-- Confirmation windows
--
--===============================================================================

---------------------------------------------------------------------------------
-- Confirm a popup menu
---------------------------------------------------------------------------------
function Wardrobe.PopupConfirm_OnClick()

	Wardrobe.NamePopup:Hide();
	Wardrobe.PopupConfirm:Hide();

	if (Wardrobe.PopupFunction == "[Add]") then
		Wardrobe.NewWardrobeName = Wardrobe.NamePopupEditBox:GetText();
		Wardrobe.ShowWardrobe_ConfigurationScreen();
	elseif (Wardrobe.PopupFunction == "[Delete]" or Wardrobe.PopupFunction == "DeleteFromSort") then
		Wardrobe.EraseOutfit(Wardrobe.NamePopupEditBox:GetText());
		if (Wardrobe.PopupFunction == "DeleteFromSort") then
			Wardrobe.PopulateMainMenu();
			Wardrobe.ToggleMainMenuFrameVisibility(true);
		end
		Wardrobe.PopupFunction = "";
	elseif (Wardrobe.PopupFunction == "[Edit]") then
		Wardrobe.NewWardrobeName = Wardrobe.NamePopupEditBox:GetText();
		Wardrobe.RenameOutfit(Wardrobe.Rename_OldName, Wardrobe.NewWardrobeName);
		Wardrobe.StoreVirtualOutfit(WARDROBE_CONSTANTS_TEMP_OUTFIT_NAME, Wardrobe.NewWardrobeName);
		Wardrobe.WearOutfit(Wardrobe.NewWardrobeName, true);
		Wardrobe.PopupFunction = "[Update]";
		Wardrobe.ShowWardrobe_ConfigurationScreen();
	elseif (Wardrobe.PopupFunction == "[Update]") then
		Wardrobe.NewWardrobeName = Wardrobe.NamePopupEditBox:GetText();
		Wardrobe.ShowWardrobe_ConfigurationScreen();
	elseif (Wardrobe.PopupFunction == "[Mounted]") then
		if (not Wardrobe.FoundOutfitName(Wardrobe.NamePopupEditBox:GetText()) or Wardrobe.NamePopupEditBox:GetText() == "") then
			Wardrobe.Print(WARDROBE_CONSTANTS_TXT_MOUNTEDNOTEXIST);
			UIErrorsFrame:AddMessage(WARDROBE_CONSTANTS_TXT_NOTEXISTERROR, 0.0, 1.0, 0.0, 1.0, UIERRORS_HOLD_TIME);
			Wardrobe.PopupFunction = "";
		else
			Wardrobe.SetMountedOutfit(Wardrobe.NamePopupEditBox:GetText());
			Wardrobe.PopupFunction = "";
		end
	end
		
end


---------------------------------------------------------------------------------
-- Cancel a popup menu
---------------------------------------------------------------------------------
function Wardrobe.PopupCancel_OnClick()
	Wardrobe.NamePopup:Hide();
	Wardrobe.PopupConfirm:Hide();
	if (Wardrobe.PopupFunction == "DeleteFromSort") then
		Wardrobe.ToggleMainMenuFrameVisibility(true);
	end
end



--===============================================================================
--
-- Paperdoll configuration windows
--
--===============================================================================

---------------------------------------------------------------------------------
-- Show the screen that lets the user confirm his/her wardrobe selection (check off items, etc)
---------------------------------------------------------------------------------
function Wardrobe.ShowWardrobe_ConfigurationScreen()
	
	local numInventorySlots = table.getn(Wardrobe.InventorySlots);
	Wardrobe.CheckboxToggleState = Wardrobe_Config.DefaultCheckboxState;
	Wardrobe.CurrentOutfitButtonColor = WARDROBE_CONSTANTS_DEFAULT_BUTTON_COLOR;
	
	for i = 1, numInventorySlots do
		getglobal("Character"..Wardrobe.InventorySlots[i].."WardrobeCheckBox"):SetCheckedTexture("Interface\\AddOns\\Wardrobe\\Images\\Check");
		--getglobal("Character"..Wardrobe.InventorySlots[i].."WardrobeCheckBox"):SetDisabledCheckedTexture("Interface\\AddOns\\Wardrobe\\Images\\X");
	end

	if (Wardrobe.PopupFunction == "[Add]") then
		if (Wardrobe_Config.DefaultCheckboxState == 1 or Wardrobe_Config.DefaultCheckboxState == 0) then
			for i = 1, numInventorySlots do
				getglobal("Character"..Wardrobe.InventorySlots[i].."WardrobeCheckBox"):SetChecked(Wardrobe_Config.DefaultCheckboxState);
			end
		else
			Wardrobe.Print(WARDROBE_CONSTANTS_TXT_WARDROBENAME..tostring(Wardrobe_Config.DefaultCheckboxState));
		end
		
	elseif (Wardrobe.PopupFunction == "[Update]") then
	
		-- for each outfit
		for i = 1, table.getn(Wardrobe_Config[WD_realmID][WD_charID].Outfit) do

			-- if it's the wardrobe we're updating
			if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].OutfitName == Wardrobe.NewWardrobeName) then

				Wardrobe.CurrentOutfitButtonColor = Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].ButtonColor;
				
				-- for each item in the outfit, set the checkbox
				for j = 1, table.getn(Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Item) do
					if (not Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Item[j].IsSlotUsed) then
						Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Item[j].IsSlotUsed = Wardrobe_Config.DefaultCheckboxState;
					end
					local IsSlotUsed = Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Item[j].IsSlotUsed;
					local checkBoxName = "Character"..Wardrobe.InventorySlots[j].."WardrobeCheckBox";
					getglobal(checkBoxName):SetChecked(IsSlotUsed);
				end
				break;
			end
		end
	end
	
	-- show the character paperdoll frame
	Wardrobe.ToggleCharacterPanel();
	
end


---------------------------------------------------------------------------------
-- Toggle the visibility of the character panel
---------------------------------------------------------------------------------
function Wardrobe.ToggleCharacterPanel(dontToggleChar)
	if (not Wardrobe.InToggleCharacterPanel) then
		Wardrobe.InToggleCharacterPanel = true;
		if (Wardrobe.ShowingCharacterPanel == false) then
			if (not dontToggleChar and (not PaperDollFrame:IsVisible())) then
				ToggleCharacter("PaperDollFrame");
			end
			Wardrobe.CheckboxesFrame:Show();
			Wardrobe.Orig_HideUIPanel = HideUIPanel;
			HideUIPanel = Wardrobe.HideUIPanel;
			Wardrobe.RefreshCharacterPanel();
			Wardrobe.ColorCycle_CharacterFrame(true);
			Wardrobe.ShowingCharacterPanel = true;
		else
			Wardrobe.CheckboxesFrame:Hide();
			CharacterNameText:SetText(UnitPVPName("player"));
			Wardrobe.ColorCycle_CharacterFrame(false);
			CharacterNameText:SetTextColor(1,1,1);
			Wardrobe.ShowingCharacterPanel = false;
			if (not dontToggleChar) then
				ToggleCharacter("PaperDollFrame");
			end
		end

		Wardrobe.InToggleCharacterPanel = false;
	end
end


---------------------------------------------------------------------------------
-- Refresh the character panel
---------------------------------------------------------------------------------
function Wardrobe.RefreshCharacterPanel()
	CharacterNameText:SetText(Wardrobe.NewWardrobeName);
	CharacterNameText:SetTextColor(WARDROBE_CONSTANTS_TEXTCOLORS[Wardrobe.CurrentOutfitButtonColor][1],WARDROBE_CONSTANTS_TEXTCOLORS[Wardrobe.CurrentOutfitButtonColor][2],WARDROBE_CONSTANTS_TEXTCOLORS[Wardrobe.CurrentOutfitButtonColor][3]);
end


---------------------------------------------------------------------------------
-- Turn on or off color cycling on the character panel
---------------------------------------------------------------------------------
function Wardrobe.ColorCycle_CharacterFrame(toggle)
	if (ColorCycle_AddTableEntry) then
		if (toggle) then
			for i = 1, table.getn(Wardrobe.InventorySlots) do
				ColorCycle_PulseWhite(
					{
						ID = "Character"..Wardrobe.InventorySlots[i].."WardrobeCheckBoxGlow";
						globalName = "Character"..Wardrobe.InventorySlots[i].."WardrobeCheckBoxGlow";
						cycleType  = "Texture";
						color	  = {0.0, 0.0, 0.0};
						speed	  = 0.05;
						pause	  = 0.25;
					}
				);	
			end			 
		else
			for i = 1, table.getn(Wardrobe.InventorySlots) do
				ColorCycle_PulseWhite(
					{
						ID	  = "Character"..Wardrobe.InventorySlots[i].."WardrobeCheckBoxGlow";
						remove  = true;
					}
				);	
			end
		end
	end
end


---------------------------------------------------------------------------------
-- Turn on or off color cycling on the character panel
---------------------------------------------------------------------------------
function Wardrobe.ColorCycle_UIPopupMenu(toggle)
	if (ColorCycle_AddTableEntry) then
		if (toggle) then
			ColorCycle_AddTableEntry( 
				{
					ID = "Wardrobe_PopupTitle";
					cycleType = "FontText";
					globalName = "Wardrobe_PopupTitle";
					startValues = WARDROBE_CONSTANTS_TEXTCOLORS[math.random(table.getn(WARDROBE_CONSTANTS_TEXTCOLORS))];
					cycleSpeed = 0.003;
					varySpeedFactor = 2, 
					okToWait = {true, true, true},
				}
			);
		else
			ColorCycle_PulseWhite(
				{
					ID	  = "Wardrobe_PopupTitle";
					remove  = true;
				}
			);	
		end
	end
end



---------------------------------------------------------------------------------
-- Hook the HideUIPanel function so that we can trap when the user closes the character panel
---------------------------------------------------------------------------------
function Wardrobe.HideUIPanel(theFrame)

	Wardrobe.Orig_HideUIPanel(theFrame);
	
	if (theFrame == getglobal("CharacterFrame")) then
		Wardrobe.CheckboxesFrame:Hide();		
		Wardrobe.ToggleCharacterPanel(true);
		HideUIPanel = Wardrobe.Orig_HideUIPanel;
		if (not Wardrobe.PressedAcceptButton) then
			UIErrorsFrame:AddMessage(WARDROBE_CONSTANTS_TXT_CHANGECANCELED, 1.0, 0.0, 0.0, 1.0, UIERRORS_HOLD_TIME); 
		end
		
		-- check to see if we should re-equip our previous outfit
		Wardrobe.CheckForEquipVirtualOutfit(WARDROBE_CONSTANTS_TEMP_OUTFIT_NAME);
	end
	
	Wardrobe.PressedAcceptButton = false;
end


---------------------------------------------------------------------------------
-- Handle when the user clicks the button to toggle all the checkboxes
---------------------------------------------------------------------------------
function Wardrobe.ToggleCheckboxes()
	if (Wardrobe.CheckboxToggleState == 1) then
		Wardrobe.CheckboxToggleState = 0;
	else
		Wardrobe.CheckboxToggleState = 1;
	end
	for i = 1, table.getn(Wardrobe.InventorySlots) do
		getglobal("Character"..Wardrobe.InventorySlots[i].."WardrobeCheckBox"):SetChecked(Wardrobe.CheckboxToggleState);
	end	
end


---------------------------------------------------------------------------------
-- When the user accepts the wardrobe confirmation screen
---------------------------------------------------------------------------------
function Wardrobe.ConfirmWardrobeConfigurationScreen()

	-- remember which items were checked and unchecked for this outfit
	Wardrobe.ItemCheckState = { };
	for i = 1, table.getn(Wardrobe.InventorySlots) do
		local val = getglobal("Character"..Wardrobe.InventorySlots[i].."WardrobeCheckBox"):GetChecked();
		if (val ~= 1) then val = 0; end
		table.insert(Wardrobe.ItemCheckState, val);
	end	
	
	if (Wardrobe.PopupFunction == "[Add]") then
		Wardrobe.AddNewOutfit(Wardrobe.NewWardrobeName, Wardrobe.CurrentOutfitButtonColor);
		Wardrobe.PopupFunction = "";
	elseif (Wardrobe.PopupFunction == "[Update]") then
		Wardrobe.UpdateOutfit(Wardrobe.NewWardrobeName, Wardrobe.CurrentOutfitButtonColor);
		Wardrobe.PopupFunction = "";
		
		-- check to see if we should re-equip our previous outfit
		Wardrobe.CheckForEquipVirtualOutfit(WARDROBE_CONSTANTS_TEMP_OUTFIT_NAME);
	end
	
	Wardrobe.PressedAcceptButton = true;
	Wardrobe.ToggleCharacterPanel();
end


---------------------------------------------------------------------------------
-- When the user rejects the wardrobe confirmation screen
---------------------------------------------------------------------------------
function Wardrobe.CancelWardrobe_ConfigurationScreen()

		-- check to see if we should re-equip our previous outfit
		Wardrobe.CheckForEquipVirtualOutfit(WARDROBE_CONSTANTS_TEMP_OUTFIT_NAME);
end


--===============================================================================
--
-- Main menu
--
--===============================================================================

---------------------------------------------------------------------------------
-- Show the main menu
---------------------------------------------------------------------------------
function Wardrobe.ShowMainMenu()

	Wardrobe.CheckForOurWardrobeID();
	
	-- clear any selected outfits
	for i = 1, table.getn(Wardrobe_Config[WD_realmID][WD_charID].Outfit) do
		Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Selected = false;
	end
	
	Wardrobe.ToggleMainMenuFrameVisibility(true);
	Wardrobe.PopulateMainMenu();
end


---------------------------------------------------------------------------------
-- Toggle the main menu visibility and color cycling
---------------------------------------------------------------------------------
function Wardrobe.ToggleMainMenuFrameVisibility(toggle)
	if (toggle) then
		Wardrobe.MainMenuFrame:Show();
	else
		Wardrobe.MainMenuFrame:Hide();
	end
	
	-- toggle color cycling
	Wardrobe.ColorCycle_MainMenuFrame(toggle);
end


---------------------------------------------------------------------------------
-- Start or stop color cycling on the modification frame
---------------------------------------------------------------------------------
function Wardrobe.ColorCycle_MainMenuFrame(toggle)
	if (ColorCycle_AddTableEntry) then
		if (toggle) then
			ColorCycle_AddTableEntry(
				{
					ID		  = "Wardrobe_MainMenuFrameTitle";
					cycleType   = "FontText";
					globalName  = "Wardrobe_MainMenuFrameTitle";
					cycleSpeed  = 0.01;
					okToWait	= {true, true, true};
				}
			);
		else
		
			-- turn off color cycling on the selected outfit
			for i = 1, WARDROBE_CONSTANTS_MAX_SCROLL_ENTRIES do
				local fs = Wardrobe["MainMenuFrameEntry"..i.."Outfit"];
				if (frameName ~= "Wardrobe_MainMenuFrameEntry"..i) then
					if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[fs.OutfitNum]) then
						Wardrobe.SetSelectionColor(false, "Wardrobe_MainMenuFrameEntry"..i.."Outfit", fs)
					end
				end
			end
			ColorCycle_RemoveEntry("Wardrobe_MainMenuFrameTitle");
		end
	end
end


---------------------------------------------------------------------------------
-- Populate the main menu
---------------------------------------------------------------------------------
function Wardrobe.PopulateMainMenu(maintainSelected)
	Wardrobe.Debug("PopulateMainMenu");

	Wardrobe.CheckForOurWardrobeID();
		
	Wardrobe.SortOutfits();
	
	-- clear any selected item
	for rowCount = 1, WARDROBE_CONSTANTS_MAX_SCROLL_ENTRIES do
		Wardrobe.SetSelectionColor(false, "Wardrobe_MainMenuFrameEntry"..rowCount.."Outfit", Wardrobe["MainMenuFrameEntry"..rowCount.."Outfit"]);
	end
	
	local fs;
	local offset = FauxScrollFrame_GetOffset(Wardrobe.SortScrollFrame);
	local rowCount, entryCount, totalExistingEntries, totalEntriesShown;  
	Wardrobe.Debug("offset = "..offset);
	
	rowCount = 1;
	entryCount = 1;
	
	for i = 1, 21 do
		Wardrobe["MainMenuFrameEntry"..i.."Icon"]:Hide();
	end
	
	while rowCount <= WARDROBE_CONSTANTS_MAX_SCROLL_ENTRIES do

		Wardrobe.Debug("rowCount = "..rowCount);
		Wardrobe.Debug("entryCount = "..entryCount);
		fs = Wardrobe["MainMenuFrameEntry"..rowCount.."Outfit"];
		if (not Wardrobe_Config[WD_realmID][WD_charID].Outfit[entryCount + offset]) then
			fs:SetText("");
			fs.r = 0;
			fs.g = 0;
			fs.b = 0;
			Wardrobe["MainMenuFrameEntry"..rowCount.."Icon"]:Hide();
			rowCount = rowCount + 1;
			
		-- if this isn't a virtual outfit
		elseif (not Wardrobe_Config[WD_realmID][WD_charID].Outfit[entryCount + offset].Virtual) then
			Wardrobe.Debug("Wasn't Virtual.  Setting text to: "..Wardrobe_Config[WD_realmID][WD_charID].Outfit[entryCount + offset].OutfitName);
			fs:SetText(Wardrobe_Config[WD_realmID][WD_charID].Outfit[entryCount + offset].OutfitName);
			local buttonColor = Wardrobe_Config[WD_realmID][WD_charID].Outfit[entryCount + offset].ButtonColor;
			fs.r = WARDROBE_CONSTANTS_TEXTCOLORS[buttonColor][1];
			fs.g = WARDROBE_CONSTANTS_TEXTCOLORS[buttonColor][2];
			fs.b = WARDROBE_CONSTANTS_TEXTCOLORS[buttonColor][3];
			if (not maintainSelected) then
				--Wardrobe_Config[WD_realmID][WD_charID].Outfit[entryCount + offset].Selected = false;
			end;
			
			-- if this outfit is selected, highlight it
			if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[entryCount + offset].Selected) then
				Wardrobe.SetSelectionColor(true, "Wardrobe_MainMenuFrameEntry"..rowCount.."Outfit", fs);
			else
				fs:SetTextColor(fs.r, fs.g, fs.b);
			end
			
			-- check to see if we should show the mounted icon
			if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[entryCount + offset].Special == "mounted") then
				-- set the texture
				Wardrobe["MainMenuFrameEntry"..rowCount.."Icon"]:SetNormalTexture("Interface\\AddOns\\Wardrobe\\Images\\Paw");
				Wardrobe["MainMenuFrameEntry"..rowCount.."Icon"]:Show();

			-- check to see if we should show the plaguelands icon
			elseif (Wardrobe_Config[WD_realmID][WD_charID].Outfit[entryCount + offset].Special == "plague") then
				-- set the texture
				Wardrobe["MainMenuFrameEntry"..rowCount.."Icon"]:SetNormalTexture("Interface\\AddOns\\Wardrobe\\Images\\Sword");
				Wardrobe["MainMenuFrameEntry"..rowCount.."Icon"]:Show();

			-- check to see if we should show the while-eating icon
			elseif (Wardrobe_Config[WD_realmID][WD_charID].Outfit[entryCount + offset].Special == "chowing") then
				-- set the texture
				Wardrobe["MainMenuFrameEntry"..rowCount.."Icon"]:SetNormalTexture("Interface\\AddOns\\Wardrobe\\Images\\Food");
				Wardrobe["MainMenuFrameEntry"..rowCount.."Icon"]:Show();

			else
				Wardrobe["MainMenuFrameEntry"..rowCount.."Icon"]:Hide();
			end
			rowCount = rowCount + 1; 
		else
			Wardrobe.Debug("Was Virtual");
			Wardrobe["MainMenuFrameEntry"..rowCount.."Icon"]:Hide();
		end
		fs.OutfitNum = entryCount + offset;
		entryCount = entryCount + 1;
	end

	FauxScrollFrame_Update(Wardrobe.SortScrollFrame, table.getn(Wardrobe_Config[WD_realmID][WD_charID].Outfit), WARDROBE_CONSTANTS_MAX_SCROLL_ENTRIES, WARDROBE_CONSTANTS_MAX_SCROLL_ENTRIES);

	return entryCount, rowCount;	
end


---------------------------------------------------------------------------------
-- when mousing over an entry in the outfit menu, highlight it
---------------------------------------------------------------------------------
function Wardrobe.MainMenuFrameEntry_OnEnter()
	local frameName, number = string.gsub(this:GetName(), "^Wardrobe_", "");
	Wardrobe[frameName.."Outfit"]:SetTextColor(1.0, 1.0, 1.0);
end


---------------------------------------------------------------------------------
-- when the mouse leaves an entry in the outfit menu, return it to its normal color (unless it's selected)
---------------------------------------------------------------------------------
function Wardrobe.MainMenuFrameEntry_OnLeave()
	local frameName, number = string.gsub(this:GetName(), "^Wardrobe_", "");
	local fs = Wardrobe[frameName.."Outfit"];
	local thenum = fs.OutfitNum;
	if (thenum) then
		if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[fs.OutfitNum]) then
			if (not Wardrobe_Config[WD_realmID][WD_charID].Outfit[fs.OutfitNum].Selected) then
				fs:SetTextColor(fs.r, fs.g, fs.b);
			end
		end
	end	
end


---------------------------------------------------------------------------------
-- when clicking on an entry in the outfit menu
---------------------------------------------------------------------------------
function Wardrobe.MainMenuFrameEntry_OnClick()
	
	--local frameName = this:GetName();
	local frameName, number = string.gsub(this:GetName(), "^Wardrobe_", "");

	-- unselect all items
	Wardrobe.UnselectAllMainMenuItems();
	
	-- select this item
	local fs = Wardrobe[frameName.."Outfit"];
	if (fs) then
		if (fs.OutfitNum) then
			if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[fs.OutfitNum] ~= nil) then
				if (not Wardrobe_Config[WD_realmID][WD_charID].Outfit[fs.OutfitNum].Selected) then
					Wardrobe_Config[WD_realmID][WD_charID].Outfit[fs.OutfitNum].Selected = true;
					Wardrobe.SetSelectionColor(true, "Wardrobe_"..frameName.."Outfit", fs);
				else
					Wardrobe_Config[WD_realmID][WD_charID].Outfit[fs.OutfitNum].Selected = false;
				end
			end	
		end	
	end	
end


---------------------------------------------------------------------------------
-- unselect all the outfits in the main menu
---------------------------------------------------------------------------------
function Wardrobe.UnselectAllMainMenuItems()

	-- unselect all the other buttons
	for i = 1, WARDROBE_CONSTANTS_MAX_SCROLL_ENTRIES do
		Wardrobe.SetSelectionColor(false, "Wardrobe_MainMenuFrameEntry"..i.."Outfit", Wardrobe["MainMenuFrameEntry"..i.."Outfit"]);
	end
	
	for i = 1, table.getn(Wardrobe_Config[WD_realmID][WD_charID].Outfit) do
		Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Selected = false;
	end
end


---------------------------------------------------------------------------------
-- set or unset the color of the selected outfit text in the main menu
---------------------------------------------------------------------------------
function Wardrobe.SetSelectionColor(toggle, theGlobal, fs)
	if (toggle) then
		if (ColorCycle_AddTableEntry) then
			ColorCycle_FlashWhite(
				{
					ID = theGlobal;
					cycleType = "FontText";
					globalName = theGlobal;
					color = {fs.r, fs.g, fs.b};
				}
			);
		else
			fs:SetTextColor(1, 1, 1);
		end
	else
		if (ColorCycle_AddTableEntry) then
			ColorCycle_FlashWhite(
				{
					ID = theGlobal;
					remove = true;
				}
			);
		end				
		fs:SetTextColor(fs.r, fs.g, fs.b);
	end
end


--===============================================================================
--
-- Main menu buttons
--
--===============================================================================

---------------------------------------------------------------------------------
-- when clicking on the new outfit button
---------------------------------------------------------------------------------
function Wardrobe.NewOutfitButtonClick()
	Wardrobe.NamePopupText:SetText(WARDROBE_CONSTANTS_TXT_NEWOUTFITNAME);
	Wardrobe.PopupFunction = "[Add]";
	Wardrobe.UnselectAllMainMenuItems();	
	Wardrobe.ToggleMainMenuFrameVisibility(false);	
	Wardrobe.NamePopup:Show();
end


---------------------------------------------------------------------------------
-- when clicking on the close button
---------------------------------------------------------------------------------
function Wardrobe.MainMenuCloseButton()
	Wardrobe.ColorCycle_MainMenuFrame(false);
	this:GetParent():Hide();
end


---------------------------------------------------------------------------------
-- when clicking on the edit outfit button
---------------------------------------------------------------------------------
function Wardrobe.EditOutfitButtonClick()
	local selectedOutfit = Wardrobe.FindSelectedOutfit();	
	
	if (selectedOutfit) then
		Wardrobe.NewWardrobeName = Wardrobe_Config[WD_realmID][WD_charID].Outfit[selectedOutfit].OutfitName;
		Wardrobe.Rename_OldName = Wardrobe.NewWardrobeName;
		Wardrobe.NamePopupText:SetText("New Name");
		Wardrobe.NamePopupEditBox:SetText(Wardrobe.NewWardrobeName);
		Wardrobe.PopupFunction = "[Edit]";
		Wardrobe.ToggleMainMenuFrameVisibility(false);	
		Wardrobe.NamePopup:Show();
	end
end


---------------------------------------------------------------------------------
-- when clicking on the update outfit button
---------------------------------------------------------------------------------
function Wardrobe.UpdateOutfitButtonClick()
	local selectedOutfit = Wardrobe.FindSelectedOutfit();	
	
	if (selectedOutfit) then
		Wardrobe.NewWardrobeName = Wardrobe_Config[WD_realmID][WD_charID].Outfit[selectedOutfit].OutfitName;
		Wardrobe.PopupFunction = "[Update]";
		Wardrobe.ShowWardrobe_ConfigurationScreen();
	end
end



---------------------------------------------------------------------------------
-- when clicking the mount button
---------------------------------------------------------------------------------
function Wardrobe.MountButtonClick()
	local outfitNum = Wardrobe.FindSelectedOutfit();
	local alreadyUsingThisOutfitForMounting = false;
	
	if (outfitNum) then
	
		if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[outfitNum].Special == "mounted") then
			UIErrorsFrame:AddMessage(Wardrobe_Config[WD_realmID][WD_charID].Outfit[outfitNum].OutfitName.." "..WARDROBE_CONSTANTS_TXT_NOLONGERWORNMOUNTERR, 0.0, 1.0, 0.0, 1.0, UIERRORS_HOLD_TIME);
			alreadyUsingThisOutfitForMounting = true;
		end
		for i = 1, table.getn(Wardrobe_Config[WD_realmID][WD_charID].Outfit) do
			if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Special == "mounted") then Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Special = ""; end
		end
		if (not alreadyUsingThisOutfitForMounting) then
			Wardrobe_Config[WD_realmID][WD_charID].Outfit[outfitNum].Special = "mounted";
			UIErrorsFrame:AddMessage(Wardrobe_Config[WD_realmID][WD_charID].Outfit[outfitNum].OutfitName.." "..WARDROBE_CONSTANTS_TXT_WORNWHENMOUNTERR, 0.0, 1.0, 0.0, 1.0, UIERRORS_HOLD_TIME);
		end

		Wardrobe.PopulateMainMenu(true);
	end	
end


---------------------------------------------------------------------------------
-- when clicking the plaguelands button
---------------------------------------------------------------------------------
function Wardrobe.PlaguelandsButtonClick()
	local outfitNum = Wardrobe.FindSelectedOutfit();
	local alreadyUsingThisOutfitForPlaguelands = false;
	
	if (outfitNum) then
	
		if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[outfitNum].Special == "plague") then
			UIErrorsFrame:AddMessage(Wardrobe_Config[WD_realmID][WD_charID].Outfit[outfitNum].OutfitName.." "..WARDROBE_CONSTANTS_TXT_NOLONGERWORNPLAGUEERR, 0.0, 1.0, 0.0, 1.0, UIERRORS_HOLD_TIME);
			alreadyUsingThisOutfitForPlaguelands = true;
		end
		for i = 1, table.getn(Wardrobe_Config[WD_realmID][WD_charID].Outfit) do
			if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Special == "plague") then Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Special = ""; end
		end
		if (not alreadyUsingThisOutfitForPlaguelands) then
			Wardrobe_Config[WD_realmID][WD_charID].Outfit[outfitNum].Special = "plague";
			UIErrorsFrame:AddMessage(Wardrobe_Config[WD_realmID][WD_charID].Outfit[outfitNum].OutfitName.." "..WARDROBE_CONSTANTS_TXT_WORNPLAGUEERR, 0.0, 1.0, 0.0, 1.0, UIERRORS_HOLD_TIME);
		end

		Wardrobe.PopulateMainMenu(true);
	end	
end


---------------------------------------------------------------------------------
-- when clicking the while eatings/drinking button
---------------------------------------------------------------------------------
function Wardrobe.ChowingButtonClick()
	local outfitNum = Wardrobe.FindSelectedOutfit();
	local alreadyUsingThisOutfitForChowing = false;
	
	if (outfitNum) then
	
		if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[outfitNum].Special == "chowing") then
			UIErrorsFrame:AddMessage(Wardrobe_Config[WD_realmID][WD_charID].Outfit[outfitNum].OutfitName.." "..WARDROBE_CONSTANTS_TXT_NOLONGERWORNEATERR, 0.0, 1.0, 0.0, 1.0, UIERRORS_HOLD_TIME);
			alreadyUsingThisOutfitForChowing = true;
		end
		for i = 1, table.getn(Wardrobe_Config[WD_realmID][WD_charID].Outfit) do
			if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Special == "chowing") then Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Special = ""; end
		end
		if (not alreadyUsingThisOutfitForChowing) then
			Wardrobe_Config[WD_realmID][WD_charID].Outfit[outfitNum].Special = "chowing";
			UIErrorsFrame:AddMessage(Wardrobe_Config[WD_realmID][WD_charID].Outfit[outfitNum].OutfitName.." "..WARDROBE_CONSTANTS_TXT_WORNEATERR, 0.0, 1.0, 0.0, 1.0, UIERRORS_HOLD_TIME);
		end

		Wardrobe.PopulateMainMenu(true);
	end	
end


---------------------------------------------------------------------------------
-- when clicking the move up or move down buttons
---------------------------------------------------------------------------------
function Wardrobe.MoveOutfit_OnClick(direction)
	local outfitNum = Wardrobe.FindSelectedOutfit();
	
	if (outfitNum) then
		local swapNum = Wardrobe.OrderOutfit(outfitNum, direction);
		Wardrobe.SortOutfits();
		Wardrobe.PopulateMainMenu(true);
	end
end


---------------------------------------------------------------------------------
-- when clicking the delete outfit button
---------------------------------------------------------------------------------
function Wardrobe.DeleteOutfit_OnClick()
	selectedOutfit = nil;
	for i = 1, table.getn(Wardrobe_Config[WD_realmID][WD_charID].Outfit) do
		if (Wardrobe_Config[WD_realmID][WD_charID].Outfit[i].Selected) then
			selectedOutfit = i;
			break;
		end
	end
	
	if (selectedOutfit) then
		Wardrobe.PopupFunction = "DeleteFromSort";
		Wardrobe.NamePopupEditBox:SetText(Wardrobe_Config[WD_realmID][WD_charID].Outfit[selectedOutfit].OutfitName);
		Wardrobe.PopupConfirm:Show();
		Wardrobe.ToggleMainMenuFrameVisibility(false);
		Wardrobe.PopupConfirmText:SetText(WARDROBE_CONSTANTS_TXT_REALLYDELETEOUTFIT.."\n\n"..Wardrobe_Config[WD_realmID][WD_charID].Outfit[selectedOutfit].OutfitName);
	else
		UIErrorsFrame:AddMessage(WARDROBE_CONSTANTS_TXT_PLEASESELECTDELETE, 1.0, 0.0, 0.0, 1.0, UIERRORS_HOLD_TIME);
	end
end


--===============================================================================
--
-- Color picker
--
--===============================================================================

---------------------------------------------------------------------------------
-- when clicking on a color in the color picker
---------------------------------------------------------------------------------
function Wardrobe.ColorPickFrameColor_OnClick()
	local selectedOutfit = Wardrobe.FindSelectedOutfit();
	local buttonName = this:GetName();
	local x, y = string.find(buttonName, "%d+");
	Wardrobe.ColorPickFrame.buttonNum = tonumber(string.sub(buttonName, x, y));
	Wardrobe.ColorPickFrameExampleText:SetTextColor(WARDROBE_CONSTANTS_TEXTCOLORS[Wardrobe.ColorPickFrame.buttonNum][1], 
												   WARDROBE_CONSTANTS_TEXTCOLORS[Wardrobe.ColorPickFrame.buttonNum][2], 
												   WARDROBE_CONSTANTS_TEXTCOLORS[Wardrobe.ColorPickFrame.buttonNum][3]);	

	if (Wardrobe.EnteredColorPickerFromPaperdollFrame) then
		Wardrobe.CurrentOutfitButtonColor = Wardrobe.ColorPickFrame.buttonNum;
	end	
end


---------------------------------------------------------------------------------
-- Show the color selection menu
---------------------------------------------------------------------------------
function Wardrobe.ShowColorPickFrame()

	-- figure out where we were called from
	if (Wardrobe.MainMenuFrame:IsVisible()) then
		Wardrobe.EnteredColorPickerFromPaperdollFrame = false;
	else
		Wardrobe.EnteredColorPickerFromPaperdollFrame = true;
	end
	
	local selectedOutfit = Wardrobe.FindSelectedOutfit();

	if (selectedOutfit or Wardrobe.EnteredColorPickerFromPaperdollFrame) then

		Wardrobe.ColorPickFrame:SetAlpha(1.0);
		Wardrobe.ColorPickFrame:Show();
		Wardrobe.ColorPickFrameGrid:SetFrameLevel(Wardrobe.ColorPickFrameGrid:GetFrameLevel() + 1);
		for i = 1, 24 do
			Wardrobe["ColorPickFrameBox"..tostring(i).."Texture"]:SetVertexColor(WARDROBE_CONSTANTS_TEXTCOLORS[i][1],WARDROBE_CONSTANTS_TEXTCOLORS[i][2],WARDROBE_CONSTANTS_TEXTCOLORS[i][3],1.0);
			Wardrobe["ColorPickFrameBox"..tostring(i)]:SetFrameLevel(Wardrobe.ColorPickFrameGrid:GetFrameLevel() - 1);
		end

		if (Wardrobe.EnteredColorPickerFromPaperdollFrame) then
			Wardrobe.ColorPickFrameExampleText:SetText(Wardrobe.NewWardrobeName);
			Wardrobe.ColorPickFrameExampleText:SetTextColor(WARDROBE_CONSTANTS_TEXTCOLORS[Wardrobe.CurrentOutfitButtonColor][1], WARDROBE_CONSTANTS_TEXTCOLORS[Wardrobe.CurrentOutfitButtonColor][2], WARDROBE_CONSTANTS_TEXTCOLORS[Wardrobe.CurrentOutfitButtonColor][3]);	
		else
			Wardrobe.ColorPickFrameExampleText:SetText(Wardrobe_Config[WD_realmID][WD_charID].Outfit[selectedOutfit].OutfitName);
			local colorNum = Wardrobe_Config[WD_realmID][WD_charID].Outfit[selectedOutfit].ButtonColor;
			Wardrobe.ColorPickFrameExampleText:SetTextColor(WARDROBE_CONSTANTS_TEXTCOLORS[colorNum][1], WARDROBE_CONSTANTS_TEXTCOLORS[colorNum][2], WARDROBE_CONSTANTS_TEXTCOLORS[colorNum][3]);	
		end
		
		if (not Wardrobe.EnteredColorPickerFromPaperdollFrame) then Wardrobe.ToggleMainMenuFrameVisibility(false); end

	end	
end


---------------------------------------------------------------------------------
-- Accept the color selection menu
---------------------------------------------------------------------------------
function Wardrobe.AcceptColorPickFrame()
	if (Wardrobe.EnteredColorPickerFromPaperdollFrame) then
		Wardrobe.RefreshCharacterPanel();
	end
	if (Wardrobe.ColorPickFrame.buttonNum) then
		Wardrobe.SetSelectedOutfitColor(Wardrobe.ColorPickFrame.buttonNum); 
		Wardrobe.PopulateMainMenu();		
	end
	Wardrobe.HideColorPickFrame();
end


---------------------------------------------------------------------------------
-- set the color of the selected outfit based on which button was clicked in the color selector
---------------------------------------------------------------------------------
function Wardrobe.SetSelectedOutfitColor(num)
	local selectedOutfit = Wardrobe.FindSelectedOutfit();

	if (selectedOutfit) then
		Wardrobe_Config[WD_realmID][WD_charID].Outfit[selectedOutfit].ButtonColor = num;		
		Wardrobe.PopulateMainMenu();
	end
end

---------------------------------------------------------------------------------
-- Hide the color selection menu
---------------------------------------------------------------------------------
function Wardrobe.HideColorPickFrame()
	if (not Wardrobe.EnteredColorPickerFromPaperdollFrame) then
		Wardrobe.ToggleMainMenuFrameVisibility(true);
	end
	Wardrobe.ColorPickFrame.buttonNum = nil;
	Wardrobe.ColorPickFrame:Hide();
end


---------------------------------------------------------------------------------
-- Show the tooltip text
---------------------------------------------------------------------------------
function Wardrobe.ShowButtonTooltip(theText1, theText2, theText3, theText4, theText5)

	-- Set the anchor and text for the tooltip.
	GameTooltip:ClearLines();
	GameTooltip:SetOwner(this, "ANCHOR_BOTTOMLEFT");
	GameTooltip:SetText(theText1, 0.39, 0.77, 0.16);
		
	-- add description lines to the tooltip
	if (theText2) then
		GameTooltip:AddLine(theText2, 0.82, 0.24, 0.79);
	end
	if (theText3) then
		GameTooltip:AddLine(theText3, 0.82, 0.24, 0.79);
	end
	if (theText4) then
		GameTooltip:AddLine(theText4, 0.82, 0.24, 0.79);
	end
	if (theText5) then
		GameTooltip:AddLine(theText5, 0.82, 0.24, 0.79);
	end
	
	-- Adjust width and height to account for new lines and show the tooltip
	-- (the Show() command automatically adjusts the width/height)
	GameTooltip:Show();
end
